@@ -103,17 +103,17 @@ K2 <- as.kform(M2,1:5)
 K2
 
 ## -----------------------------------------------------------------------------
-K1 %^% K2
+K1 ^ K2
 
 ## -----------------------------------------------------------------------------
 F1 <- as.kform(matrix(c(3,4,5, 4,6,1,3,2,1),3,3,byrow=TRUE))
 F2 <- as.kform(cbind(1:6,3:8),1:6)
 F3 <- kform_general(1:8,2)
-(F1 %^% F2) %^% F3
-F1 %^% (F2 %^% F3)
+(F1 ^ F2) ^ F3
+F1 ^ (F2 ^ F3)
 
 ## -----------------------------------------------------------------------------
-(F1 %^% F2) %^% F3 - F1 %^% (F2 %^% F3)
+(F1 ^ F2) ^ F3 - F1 ^ (F2 ^ F3)
 
 ## -----------------------------------------------------------------------------
 Krel <- kform_general(4,2,1:6)
@@ -138,6 +138,14 @@ K <- kform_general(3,2,1:3)
 K
 as.symbolic(K,d="d",symbols=letters[23:26])
 
+## -----------------------------------------------------------------------------
+options(stokes_symbolic_print = TRUE)
+K
+
+## -----------------------------------------------------------------------------
+(d(1) + d(5)) ^ (d(3)-5*d(2)) ^ d(7)
+options(stokes_symbolic_print = FALSE) # restore default
+
 ## -----------------------------------------------------------------------------
 (o <- rform())  # a random 3-form
 V <- matrix(runif(21),ncol=3)
@@ -155,15 +163,14 @@ contract(o,V)
 contract(o,V,lose=FALSE)
 
 ## -----------------------------------------------------------------------------
-(o <- 2 * as.kform(2) %^% as.kform(4) %^% as.kform(5))
+(o <- 2 * as.kform(2) ^ as.kform(4) ^ as.kform(5))
 M <- matrix(rnorm(25),5,5)
 
 ## -----------------------------------------------------------------------------
-library("magrittr")
-(o %<>% transform(M) %>% transform(solve(M)))
+zap(o |> transform(M) |> transform(solve(M)))
 
 ## -----------------------------------------------------------------------------
-as.kform(index(o),zapsmall(value(o)))
+as.kform(index(o),zapsmall(coeffs(o)))
 
 ## -----------------------------------------------------------------------------
 grad(c(0.4,0.1,-3.2,1.5))
@@ -190,7 +197,7 @@ df(1:5)
 
 ## -----------------------------------------------------------------------------
 x <- rnorm(9)
-print(df(x) %^% f(x))  # should be zero
+print(df(x) ^ f(x))  # should be zero
 
 ## -----------------------------------------------------------------------------
 f1 <- function(w,x,y,z){x + y^3 + x*y*w*z}
@@ -206,21 +213,21 @@ dz <- as.kform(4)
 ## -----------------------------------------------------------------------------
 phi <-
   (
-    +f1(1,2,3,4) %^% dw %^% dx
-    +f2(1,2,3,4) %^% dw %^% dy
-    +f3(1,2,3,4) %^% dy %^% dz
+    +f1(1,2,3,4) ^ dw ^ dx
+    +f2(1,2,3,4) ^ dw ^ dy
+    +f3(1,2,3,4) ^ dy ^ dz
   )
 
 ## -----------------------------------------------------------------------------
-e1 <- dw %^% dx
-e2 <- dw %^% dy
-e3 <- dy %^% dz
+e1 <- dw ^ dx
+e2 <- dw ^ dy
+e3 <- dy ^ dz
 
 phi <-
   (
-    +f1(1,2,3,4) %^% e1
-    +f2(1,2,3,4) %^% e2
-    +f3(1,2,3,4) %^% e3
+    +f1(1,2,3,4) ^ e1
+    +f2(1,2,3,4) ^ e2
+    +f3(1,2,3,4) ^ e3
   )
 phi
 
@@ -236,9 +243,9 @@ Df1
 ## -----------------------------------------------------------------------------
 dphi <-
   (
-    +grad(Df1) %^% e1
-    +grad(Df2) %^% e2
-    +grad(Df3) %^% e3
+    +grad(Df1) ^ e1
+    +grad(Df2) ^ e2
+    +grad(Df3) ^ e3
   )
 dphi
 
