@@ -7,15 +7,15 @@ test_that("Function hodge() behaves itself", {
     foo1 <- function(x){  # checks that ***x == x, also positivity
 
         n <- max(index(x))
-        discrepancy <- x %>% hodge(n) %>% hodge(n) %>% hodge(n) %>% hodge(n) - x
+        discrepancy <- x |> hodge(n) |> hodge(n) |> hodge(n) |> hodge(n) - x
         expect_true(issmall(discrepancy),info=x)
-        expect_true(value(x %^% hodge(x,n)) >= 0)
+        expect_true(all(coeffs(x %^% hodge(x,n)) >= 0))
     } # foo1() closes
 
 
     foo2 <- function(x,y){  # checks that *x^y == *y^x
         n <- max(c(index(x),index(y)))
-        expect_true(issmall(hodge(x,n) %^% y - hodge(y,n) %^% x),info=list(x,y,n))
+        expect_true(issmall(hodge(x,n) ^ y - hodge(y,n) ^ x),info=list(x,y,n))
     }  # foo2() closes
 
 
